# Blueprints Roadmap

This document outlines the current and upcoming features in Blueprints. You can also find templates for making formulas in our [discussions](https://github.com/orgs/Blueprints-org/discussions/432).

## Progress Definitions

| Icon | Definition |
|------|------------|
| ![20%](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange) | Just started |
| ![50%](https://img.shields.io/badge/50-%25-grey?style=plastic&labelColor=yellow) | Making progress |
| ![80%](https://img.shields.io/badge/80%25--grey?style=plastic&labelColor=yellowgreen) | In Review |
| ✔️ | Done |

## Eurocode Formulas

* Eurocode formulas
    - [ ] EN 1992-1-1:2004 ![](https://img.shields.io/badge/80-%25-grey?style=plastic&labelColor=yellowgreen)
    - [ ] EN 1993-1-1:2005 ![](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange) 
    - [ ] EN 1993-1-9:2005 ![](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange)    
    - [ ] EN 1993-5:2007 ![](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange)           
    - [ ] NEN 9997-1+C2:2017 ![](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange)

## Material Definitions

* Material definitions
    - [x] Concrete (NEN-EN 1992) ✔️
    - [x] Rebar Steel (NEN-EN 1992) ✔️
    - [x] Steel (NEN-EN 1993) ✔️
    - [x] Soil (NEN-EN 1997) ✔️

## Steel Profile Database

* Common steel profile database
    - [x] HEA / HEB / HEM / IPE ✔️
    - [x] CHS ✔️
    - [x] RHS / SHS / RHSCF / SHSCF ✔️
    - [x] UNP ✔️
    - [x] Strips ✔️
    - [ ] Sheetpiles

## Shape Building Blocks

* Shape building blocks
    - [x] Rectangle ✔️
    - [x] Circle ✔️
    - [x] Tube / ring ✔️
    - [x] Right triangle ✔️
    - [x] Hexagon ✔️
    - [x] A circular cornered section ✔️
    - [ ] Annular Sector (partial ring) ![](https://img.shields.io/badge/Status-In%20Pull%20Request-yellowgreen)

## Reinforced Concrete Section

* Reinforced Concrete Section
    - [x] Rectangular section ✔️
    - [x] Circular section ✔️

## Strain-Stress Analysis

* Strain-stress analysis for reinforced concrete sections:
  - [ ] Rectangular section ![](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange)
  - [ ] Circular section 

## Concrete Checks

* Concrete checks
  - [x] Creep and Shrinkage (EN 1992-1-1: Chapter 3.1.4) ✔️
  - [x] [Nominal concrete cover (EN 1992-1-1: Chapter 4)](https://cloud.viktor.ai/public/blueprints-nominal-concrete-cover) ✔️
  - [x] Anchorage- and Laplengths (EN 1992-1-1: Chapter 8) ✔️
  - [x] Shear Resistance (EN 1992-1-1: Chapter 6.2) ✔️
  - [x] Shear Resistance circular shapes ✔️
  - [x] Torsion (EN 1992-1-1: Chapter 6.3) ✔️
  - [x] Punching Shear (EN 1992-1-1: Chapter 6.4) ✔️
  - [ ] Fatigue (EN 1992-1-1: Chapter 6.8) ![](https://img.shields.io/badge/Status-In%20Pull%20Request-yellowgreen)
  - [ ] Crack Control (EN 1992-1-1: Chapter 7.3) ![](https://img.shields.io/badge/Status-In%20Pull%20Request-yellowgreen)

## Other Engineering Disciplines

* Timber checks (NEN-EN 1995)
   - *To Be Determined*

* Steel checks (NEN-EN 1993)
  - *To Be Determined*

* Geotechnical checks (NEN-EN 9997-1)
  - *To Be Determined*

## Common Calculations

* Common calculations
  - [ ] Sheet-pile checks (strength and local buckling) ![](https://img.shields.io/badge/20%25-grey?style=plastic&labelColor=orange)
  - [ ] L-walls
  - [ ] Spring constants calculations for piles
